********************************************************************************
********************************************************************************
***************************clear and append all data****************************
********************************************************************************
********************************************************************************

clear all

cd "/Users/sambuehl/Dropbox/Paternalism/SUBMISSIONS/NBER/dataAndCode/appendixSurvey"
 
set more off

import delimited "data/batch1.csv", delimiter(comma) bindquote(nobind) varnames(1) case(preserve) 

gen session = 1

*keep only those who finished
keep if employment ~= . 

*drop double participant
drop if amt == "A3OZ5DRX0ARFM4" 

*correct~ are binary variables where they show 1 if correct, 0 if not
gen correct1sugar 	= checkSugar1 	== 2
gen correct2sugar 	= checkSugar2 	== 2
gen correct1alc 	= checkAlc1 	== 2
gen correct2alc 	= checkAlc2 	== 2
gen correct1loans 	= checkLoans1 	== 10
gen correct2loans 	= checkLoans2 	== 3
gen correct1ret 	= checkRet1 	== 3
gen correct2ret 	= checkRet2 	== 5

*sum all answers to comprehension check questions
gen sumCorrect = ///
	correct1sugar + ///
	correct2sugar + ///
	correct1alc + ///
	correct2alc + ///
	correct1loans + ///
	correct2loans + ///
	correct1ret + ///
	correct2ret
	
keep if sumCorrect == 8

gen id = _n

********************************************************************************
********************************************************************************
*************************modifying vairiables as needed*************************
********************************************************************************
********************************************************************************

*replace value with . when participants chose not to answer questions about themselves
replace bmiSelf = . if bmiSelf == 6
replace income = . if income == -9999
replace ccDebt = . if ccDebt == 10
replace paydayLoan = . if paydayLoan == 5
replace debtCycle = . if debtCycle == 5
replace savings = . if savings == 13 | savings == 14

*creating belief variables for each policy
foreach var in sugar alc loans ret {
	gen beliefBin1`var' = 0
	gen beliefBin2`var' = 0
	gen beliefBin3`var' = 0

	forvalues i = 1 / 10 {
		replace beliefBin1`var' = beliefBin1`var' + 1 if dist_`var'_0_GROUP_`i' == 1
		replace beliefBin2`var' = beliefBin2`var' + 1 if dist_`var'_1_GROUP_`i' == 1
		replace beliefBin3`var' = beliefBin3`var' + 1 if dist_`var'_2_GROUP_`i' == 1
	}
		

	replace beliefBin1`var' = beliefBin1`var' / 10		
	replace beliefBin2`var' = beliefBin2`var' / 10		
	replace beliefBin3`var' = beliefBin3`var' / 10		
		
	*to check if sums up to 1	
	gen beliefBinTest`var' = beliefBin1`var' + beliefBin2`var' + beliefBin3`var'
	

	rename beliefBin1`var' beliefBetter`var'		
	rename beliefBin2`var' beliefSame`var'		
	rename beliefBin3`var' beliefWorse`var'		
	
}

gen eff_ret = 0

*rename variables ending with {sugar; alc; loans; ret} to ending with {1; 2; 3; 4} instead
local i = 0
foreach var in sugar alc loans ret { 
	local i = `i' + 1
	rename indSupp_`var' 		indSupp`i'
	rename indWelf_`var'		indWelf`i'
	rename eff_`var'			eff`i'
	rename overall_`var'		overall`i'
	rename ext_`var'			ext`i'
	rename beliefBetter`var'	beliefBetter`i'	
	rename beliefSame`var'		beliefSame`i'
	rename beliefWorse`var'		beliefWorse`i'	
	rename correct1`var'		correct1`i'	
	rename correct2`var'		correct2`i'	
}

rename orderSugar 	proConOrder1
rename orderAlc 	proConOrder2
rename orderLoan 	proConOrder3
rename orderRet 	proConOrder4

rename FL_22_DO_FL_25 order1
rename FL_22_DO_FL_31 order2
rename FL_22_DO_FL_29 order3
rename FL_22_DO_FL_27 order4		

gen height = 12 * height_1 + height_2

********************************************************************************
********************************************************************************
***************************cleaning own characteristics*************************
********************************************************************************
********************************************************************************

gen bmiObj = weight / height^2 * 703
rename bmiSelf bmiSubj

rename Q57 alcCons
rename Q58 alcBinge

*interval midpoints are used for analysis
*coded as alcohol consumption from high to low
gen alcConsNew = .
replace alcConsNew = 10 	if alcCons == 1
replace alcConsNew = 7.5    if alcCons == 2
replace alcConsNew = 4 	    if alcCons == 3
replace alcConsNew = 2 	    if alcCons == 4
replace alcConsNew = 0.5    if alcCons == 5
replace alcConsNew = 0 	    if alcCons == 6
replace alcCons = alcConsNew
drop alcConsNew

*interval midpoints are used for analysis
*coded as number of days in year in which binge-drinking happened from high to low
gen alcBingeNew = .
replace alcBingeNew = 7*52		if alcBinge == 1
replace alcBingeNew = 5.5*52	if alcBinge == 2
replace alcBingeNew = 3.5*52	if alcBinge == 3
replace alcBingeNew = 2*52		if alcBinge == 4
replace alcBingeNew = 1*52		if alcBinge == 5
replace alcBingeNew = 2.5*12	if alcBinge == 6
replace alcBingeNew = 7			if alcBinge == 7
replace alcBingeNew = 1.5		if alcBinge == 8
replace alcBingeNew = 0			if alcBinge == 9
replace alcBinge = alcBingeNew 
drop alcBingeNew

*interval midpoints are used for analysis
*coded as dollar amount from low to high
gen ccDebtNew = .
replace ccDebtNew = 250		if ccDebt == 1
replace ccDebtNew = 750		if ccDebt == 2
replace ccDebtNew = 1250	if ccDebt == 3
replace ccDebtNew = 3750	if ccDebt == 4
replace ccDebtNew = 6250	if ccDebt == 5
replace ccDebtNew = 8750	if ccDebt == 6
replace ccDebtNew = 15000	if ccDebt == 7
replace ccDebtNew = 35000	if ccDebt == 8
replace ccDebtNew = 65000	if ccDebt == 9
replace ccDebt = ccDebtNew 
drop ccDebtNew

*Normalize money variables by individual income
gen ccDebtByIncome = 1000*ccDebt / income

*interval midpoints are used for analysis
*savings are coded in thousands from low to high
gen savingsNew = .
replace savingsNew = 0 			if savings == 1
replace savingsNew = 5 			if savings == 2
replace savingsNew = 12.5 		if savings == 3
replace savingsNew = 37.5 		if savings == 4
replace savingsNew = 75 		if savings == 5
replace savingsNew = 150 		if savings == 6
replace savingsNew = 250 		if savings == 7
replace savingsNew = 350 		if savings == 8
replace savingsNew = 450 		if savings == 9
replace savingsNew = 625 		if savings == 10
replace savingsNew = 875 		if savings == 11
replace savingsNew = 1000 		if savings == 12
replace savings = savingsNew
drop savingsNew

*normalize money variables by individual income
gen savingsByIncome = 1000*savings / income

*interval mispoints are used for analysis
*savings rate are coded as % from low to high
gen savingsRateNew = .
replace savingsRateNew = 0 		if savingsRate == 1
replace savingsRateNew = 1.25 	if savingsRate == 2
replace savingsRateNew = 3.75 	if savingsRate == 3
replace savingsRateNew = 6.25 	if savingsRate == 4
replace savingsRateNew = 8.75 	if savingsRate == 5
replace savingsRateNew = 12.5 	if savingsRate == 6
replace savingsRateNew = 17.5 	if savingsRate == 7
replace savingsRateNew = 25 	if savingsRate == 8
replace savingsRateNew = 35 	if savingsRate == 9
replace savingsRate = savingsRateNew
drop savingsRateNew 

*code such that projective paternalism predicts negative relation between predictor and policy support 
gen ownA1 = bmiObj
gen ownB1 = bmiSubj
gen ownA2 = alcCons
gen ownB2 = alcBinge
gen ownA3 = ccDebtByIncome  
gen ownB3 = paydayLoan
gen ownA4 = -savingsByIncome
gen ownB4 = -savingsRate

*standardize own characteristics (independent variables)
foreach var in ownA1 ownB1 ownA2 ownB2 ownA3 ownB3 ownA4 ownB4  {
	su `var'
	replace `var' = (`var' - r(mean))/r(sd)
}

gen own1 = (ownA1 + ownB1) / 2
gen own2 = (ownA2 + ownB2) / 2
gen own3 = (ownA3 + ownB3) / 2
gen own4 = (ownA4 + ownB4) / 2

*how participants feel about their own situation
gen happy1 = happySugar
gen happy2 = happyAlc
gen happy3 = happyLoan
gen happy4 = happyRet

*create long format of data
reshape long ///
		indSupp indWelf eff overall ext beliefBetter beliefSame beliefWorse ///
		own ownA ownB correct1 correct2 proConOrder happy order ///
		, i(id) j(policy)
	
*for each policy, gives the first principal component of the subjects' responses to the two questions their own characteristics corresponding to that policy
	gen ownPCA = .
	
forvalues i = 1 / 4 {
	pca ownA ownB if policy == `i'
	predict ownPCA`i'
	replace ownPCA = ownPCA`i' if policy == `i'
}
	replace own = ownPCA

********************************************************************************
********************************************************************************
****************************scaling dependent variables*************************
********************************************************************************
********************************************************************************

*make indSupp either positive or negative symmetrically with equal distances between each pair of answers; positive for support negative for object
replace indSupp = 3 - indSupp 
replace indSupp = indSupp - 1 if indSupp <=0
replace indSupp = indSupp + 0.5 if indSupp < 0 
replace indSupp = indSupp - 0.5 if indSupp > 0 

replace overall = 3 - overall 
replace overall = overall - 1 if overall <=0

replace ext = ext - 2 if ext >= 4
replace ext = 4 - ext
replace ext = ext - 1 if ext <= 0

*sugar: low more effective
*alc: low more effective
*loans: high more effective

*recode sugar and alc such that high always means more effective
replace eff = 7 - eff if policy == 1 | policy == 2

replace eff = eff - 3.5 if policy ~= 4
replace eff = 0 if policy == 4

replace polit = polit - 3 // higher = more liberal

*pooling education equiv or under high school level to 3 and education equiv or above college to 6 in order to avoid extremely small categories that would have unduly large weight on the results
replace educ = 3 if educ <= 3
replace educ = 6 if educ >= 6

gen meanBelief = beliefBetter - beliefWorse

gen sdBelief = 	  (1 - meanBelief)^2 * beliefBetter /// 
				+ (0 - meanBelief)^2 * beliefSame ///
				+ (-1 - meanBelief)^2 * beliefWorse

				
********************************************************************************
********************************************************************************
**************************labelling variables***********************************
********************************************************************************
********************************************************************************

egen tag = tag(id)

replace debtCycle = debtCycle - 1

replace indWelf = 3 - indWelf

replace age = age + 17

replace happy = 3 - happy

replace paydayLoan = paydayLoan - 1

gen logInc = log(income)

gen durationMinutes = Duration / 60

gen logDuration = log(duration)

la de policy 1 "sugar" 2 "alc" 3 "loans" 4 "retirement"
la val policy policy
la var policy "Policy"

la var id "ID"
la var Durationinseconds "Duration in Seconds"
la var ResponseId "Response ID"

la var indSupp   "Supportiveness of Policy"

la de indWelf -2 "much better off" -1 "a little better off" 0 "equally well off" 1 "a little worse off" 2 "much worse off"
la val indWelf indWelf
la var indWelf   "Belief on Effectiveness of Policy"

la de overall 2 "strong support" 1 "weak support" -1 "weak oppose" -2 "strong oppose"
la val overall overall
la var overall "Supportiveness of Proposed Policy given Context on Societal Benefit"

la de ext 3 "exclusively the change in well-being" 2 "mostly the change in well-being" 1 "both but a little more the change of well-being" -1 "both, but a little more the effects on society at large" -2 "mostly the effects on society at large" -3 "exclusively the effects on society at large"
la val ext ext
la var ext "Main Determinant of Supportiveness for Policy"

la var age "Age"

la de male 0 "Female" 1 "Male"
la val male male
la var male "Gender"

la var alcCons "Units of Average Alcohol Consumption in a Week"
la var alcBinge "Number of Days in Year in which Binge-drinking Happened"

la var weight "Weight"
la var bmiObj "BMI Objective"

la de weight 1 "underweight" 2 "healthy weight" 3 "overweight" 4 "moderately obese" 5 "severely obese"
la val bmiSubj weight 
la var bmiSubj "BMI Subjective"

la var income "Annual Household Income"
la var ccDebt "Credit Card Debt Amount"

la de paydayLoan 0 "never" 1 "once" 2 "multiple" 3 "often"
la val paydayLoan paydayLoan
la var paydayLoan "Payday Loan"

la de debtCycle 0 "never" 1 "once" 2 "multiple" 3 "often"
la val debtCycle debtCycle
la var debtCycle "Debt Cycle"

la var savings "Total Retirement Savings in Thousands"
la var savingsRate "Percentage of Income Contributed to Retirement Savings"

la de political -2 "conservative" -1 "leaning conservative" 0 "centrist" 1 "leaning liberal" 2 "liberal"
la val political political
la var political "Political Stance"

la de urban 1 "urban" 2 "suburban" 3 "rural"
la val urban urban
la var urban "Living Conditions" 

la de employment 1 "upemployed" 2 "employed part-time " 3 "employed full-time "
la val employment employment
la var employment "Employment Status"

la var order "Sequence of Policy Presented to Participant"
la var proConOrder "Whether Arguments in Favor of the Interventions were Mentioned First"

la var sumCorrect "Number of Correctly Answered Check Questions"

la var height "Height in Inches"
la var ccDebtByIncome "credit Card Debt Scaled by Income"
la var savingsByIncome "Retirement Savings Scaled by Income"

la var tag "Tag"
la var logInc "Log(Income)"
la var durationMinutes "Duration in Minutes"
la var logDuration "Log(Duration)"

la var eff "Effectiveness of Policy"

la de happy 2 "perfectly comfortable" 1 "fairly comfortable" 0 "neither nor" -1 "fairly uncomfortable" -2 "completely uncomfortable" 
la val happy happy 
la var happy "Self Perception towards Own Characteristics"




********************************************************************************
********************************************************************************
****************drop variables not needed in our code***************************
********************************************************************************
********************************************************************************

drop amt *RANK Q* FL* belief* *GROUP* *Date Status IPAddress Progress Finished RecordedDate *sugar_DO*
drop Recipient* ExternalReference Location* DistributionChannel UserLanguage meta*
drop *Loans2_DO* SC0 one counter excluded n1 n2 sum check* retSavingsPlan correct1 correct2
drop height_1 height_2 happyAlc happyLoans happyRet happySugar session 
drop *Belief 

keep if sumCorr == 8

replace age = age + 17

save "data/data.dta", replace

	





********************************************************************************
********************************************************************************
****************		  ANALYSIS 					 ***************************
********************************************************************************
********************************************************************************





// Summary statistics
if 1 {
	su dura,d
	tab indSupp if policy == 1
	tab indSupp if policy == 2
	tab indSupp if policy == 3
	tab indSupp if policy == 4

	tab overall if policy == 1
	tab overall if policy == 2
	tab overall if policy == 3
	tab overall if policy == 4

	tab eff if policy == 1
	tab eff if policy == 2
	tab eff if policy == 3
	tab eff if policy == 4
	
	tab happy if policy == 1
	tab happy if policy == 2
	tab happy if policy == 3
	tab happy if policy == 4
	
	
	
	
	su bmiObj			if tag == 1
	tab bmiSubj			if tag == 1
	tab alcCons			if tag == 1
	tab alcBinge		if tag == 1
	tab ccDebt  		if tag == 1
	tab paydayLoan		if tag == 1
	tab debtCycle		if tag == 1
	tab savings			if tag == 1
	tab savingsRate		if tag == 1
	
	// scatter bmiObj bmiSubj
	reg alcCons alcBinge
	// scatter ccDebt paydayL
	
	tab debtCycle paydayL if tag == 1
	reg debtCycle paydayL if tag == 1
	
	tab savings
	tab savingsByIncome
	
	
}


// main results

replace own = ownPCA

if 1 {
	local controls = "i.order proConOrder logDuration i.sumCorr age i.male i.educ"
	foreach depVar in "overall" eff "indSupp" {
		oprobit `depVar' own `controls' if policy == 2, cl(id)
		local n = e(N_clust)
		outreg2 own using "tables/`depVar'.tex", ///
			dec(3) adec(0) ///
			addtext("Policy", "Alcohol") ///
			addstat("subj", `n') /// 
			tex replace
		oprobit `depVar' own `controls' if policy == 1, cl(id)
		local n = e(N_clust)
		outreg2 own using "tables/`depVar'.tex", ///
			dec(3) adec(0) ///
			addtext("Policy", "Sugar") ///
			addstat("subj", `n') /// 
			tex
		if ("`depVar'"~="eff") {
		oprobit `depVar' own `controls' if policy == 4, cl(id)
		local n = e(N_clust)
		outreg2 own using "tables/`depVar'.tex", ///
			dec(3) adec(0) ///
			sortvar(own eff happy cut*) ///
			addtext("Policy", "Retirement") ///
			addstat("subj", `n') /// 
			tex(frag)
		}
		oprobit `depVar' own `controls' if policy == 3, cl(id)
		local n = e(N_clust)
		outreg2 own using "tables/`depVar'.tex", ///
			dec(3) adec(0) ///
			addtext("Policy", "Loans") ///
			addstat("subj", `n') /// 
			tex(frag)
	}
}


// Demographics

if 1 {


	local demographics = "political age male i.educ i.urban employment"
	local controls = "i.order proConOrder logDuration i.sumCorr"

	reg indSupp `demographics' `controls', cl(id)
	reg indSupp `demographics' `controls' if policy == 1, cl(id)
	reg indSupp `demographics' `controls' if policy == 2, cl(id)
	reg indSupp `demographics' `controls' if policy == 3, cl(id)
	reg indSupp `demographics' `controls' if policy == 4, cl(id)


}








